@@ -9,9 +9,7 @@ def run_server(config_path: Path, port: int = 8000, workers: int = 1) -> None:
     try:
         import uvicorn
     except ImportError:
-        raise ImportError(
-            "Not installed in server mode. Install with 'pip install nomos[serve]'"
-        )
+        raise ImportError("Not installed in server mode. Install with 'pip install nomos[serve]'")
 
     os.environ["CONFIG_PATH"] = str(config_path)
     uvicorn.run("nomos.api.app:app", host="0.0.0.0", port=port, workers=workers)
